<?php
/**
 * Plugin Name: WikiTip Knowledge Cluster ToolTip for Wordpress
 * Plugin URI: http://wikitip.info/website-integration/
 * Description: Use terms definitions from knowledge clusters at wikitip.info
 * Author: Richard Vencu
 * Author URI: http://richardconsulting.ro
 * Version: 0.1.3
 * License: GPLv2, MIT, GNU
 *
 *  1. Copyright 2011  Richard Vencu  (email : richard.vencu@richardconsulting.ro)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
	
	2. Redistribution of "Simple PHP Proxy" Version: 1.6 script
	Project Home - http://benalman.com/projects/php-simple-proxy/
	GitHub       - http://github.com/cowboy/php-simple-proxy/
	Source       - http://github.com/cowboy/php-simple-proxy/raw/master/ba-simple-proxy.php
	Copyright (c) 2010 "Cowboy" Ben Alman,
	Dual licensed under the MIT and GPL licenses.
	http://benalman.com/about/license/
	
	3. Redistribution of "jQuery Thesaurus" (jquery.thesaurus.js) script licensed under GNU
	@copyright (c) Dmitry Sheiko http://www.cmsdevelopment.com

*/
$wikitip_all_blogs = array();
$postId = 0;

register_activation_hook ( __FILE__ , 'wikitip_install' );

register_deactivation_hook ( __FILE__ , 'wikitip_deactivation' );

add_action( 'after_setup_theme', 'wikitip_setup' );

require_once('wikitip_post_metabox.php');

function wikitip_install() {

	/* Declare default values */
	$wikitip_options = array(
	
		'username' => '',

		'secret' => '',

		'domain' => '',
		
		'cluster' => '',
		
		'casesensitive' => 0,

		'containers' => '',

		'delay' => 250,
		
		'effect' => '',
		
		'frontpage' => 0,
		
		'search' => 0,
		
		'archive' => 0,
		
		'author' => 0,

		'category' => 0,

		'tag' => 0,
		
		'loggedinonly' => 1,
		
		'salt' => '',
		
		'minsize' => 1,
		
		'zindex' => 'auto',
		
		'expr' => 0

	);
	
	/* At first activation push values to database */
	if ( is_multisite() ) {

		global $wikitip_all_blogs;
	
		wikitip_retrieve_blogs();
	
		foreach ($wikitip_all_blogs as $blog) {
			if ( !get_blog_option($blog , 'wikitip_options') )
				update_blog_option ($blog , 'wikitip_options' , $wikitip_options);
		}
	} else {
		if ( !get_option('wikitip_options') )
			update_option ('wikitip_options',$wikitip_options);
	}
}

function wikitip_deactivation() {

	/* Delete options */
}

function wikitip_setup() {

	/* Load translation */
	load_plugin_textdomain ('wikitip', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

	/* Add filters, actions, and theme-supported features. */

	/* Add theme-supported features. */

	/* Add custom actions. */
	add_action ('loop_start','wikitip_displayon');
	add_action ('admin_menu','wikitip_admin_page');
	add_action ('admin_init', 'wikitip_admin_init');
	add_action ('wpmu_new_blog','wikitip_init_newblog');
	/* Add custom filters. */

}

function wikitip_init_newblog() {
	global $blog_id;
	
	/* Declare default values */
	$wikitip_options = array(
	
		'username' => '',

		'secret' => '',

		'domain' => '',
		
		'cluster' => '',
		
		'casesensitive' => 0,

		'containers' => '',

		'delay' => 250,
		
		'effect' => '',
		
		'frontpage' => 0,
		
		'search' => 0,
		
		'archive' => 0,
		
		'author' => 0,

		'category' => 0,

		'tag' => 0,
		
		'loggedinonly' => 1,
		
		'salt' => '',
		
		'minsize' => 1,
		
		'zindex' => 'auto',
		
		'expr' => 0

	);
	
	update_blog_option ($blog_id , 'wikitip_options' , $wikitip_options);

}

function wikitip_load_header() {
	/* enqueue css and js files */
	
	wp_enqueue_style('wikitip_style', plugins_url( '/css/wikitip.css', __FILE__ ) );
	
	wp_register_script( 'thesaurus_js', plugins_url( '/js/jquery.thesaurus.min.js', __FILE__ ) , array('jquery'), '');

    wp_enqueue_script( 'thesaurus_js' );

}

function wikitip_load_footer() {

	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');

	$nonce = '';
	for ($i = 0; $i < 10; $i++) { 
		$nonce .= substr("./ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789", mt_rand(0, 63), 1); 
	} 

	$username = $wikitip_options['username'];
	$secret = $wikitip_options['secret'];
	$cluster = $wikitip_options['cluster'];
	$salt = $wikitip_options['salt'];
	$minsize = $wikitip_options['minsize'];
	$containers = $wikitip_options['containers'];
	$delay = $wikitip_options['delay'];
	$domain = $wikitip_options['domain'];
	$expr = $wikitip_options['expr'];
	
	$zindex = $wikitip_options['zindex'];
	if (empty($zindex))
		$zindex = 'auto';
		
	
	
	$url = wikitip_url();
	
	$effect = $wikitip_options['effect'];
	if (empty($effect))
		$effect = 'null';
	
	$case = $wikitip_options['casesensitive'];
	$casesensitive = 'false';
	if ($case == 1)
		$casesensitive = 'true';

	$timestamp = time();
	$key = get_JSON_APIkey($nonce,$secret.$timestamp,$salt);
	
	$terms_uri = 'http://' . $cluster . '.wikitip.info/apis/richard/get_network_thesaurus/?user=' . $username .'&key='. $key . '&nonce=' . $nonce . '&timestamp=' . $timestamp . '&minsize=' . $minsize . '&expr=' . $expr;
	$def_uri = 'http://' . $cluster . '.wikitip.info/apis/richard/get_network_posts_by_wikiterm/?user=' . $username .'&key='. $key . '&nonce=' . $nonce . '&timestamp=' . $timestamp . '&wikiterm=';
	//$remote_post_uri = urlencode('http://wikitip.info/json-post-data/?user=' . $username .'&key='. $key . '&nonce=' . $nonce . '&timestamp=' . $timestamp . '&domain=' . $domain . '&url=' . $url . '&cluster=' . $cluster);
	$remote_post_uri = urlencode('http://' . $cluster . '.wikitip.info/apis/richard/get_network_thesaurus/?user=' . $username .'&key='. $key . '&nonce=' . $nonce . '&timestamp=' . $timestamp . '&domain=' . $domain . '&url=' . $url . '&cluster=' . $cluster . '&minsize=' . $minsize . '&expr=' . $expr);
	$local_post_uri = plugin_dir_url(__FILE__) . 'ba-simple-proxy.php';

	?>
	<script type="text/javascript">
	<!--
	var TOOLTIP_LOADING_TPL = '<?php _e('Loading','wikitip'); ?>...',
    TOOLTIP_BODY_TPL = '<div class="thesaurus-header"><a class="reference" target="_blank" href="http://wikitip.info/"><?php _e('A WikiTip Cluster','wikitip'); ?></a><a class="term"></a></div><div class="thesaurus-body"></div>',
	zetind = '<?php echo $zindex; ?>';

	jQuery.Thesaurus({
		caseSentitive: <?php echo $casesensitive; ?>,
		zetind: '<?php echo $zindex; ?>',
		delay: <?php echo $delay; ?>, 
		containers: ['<?php echo $containers; ?>'],
		effect: '<?php echo $effect; ?>',
		JSON_TERMS_URI : '<?php echo $terms_uri ?>',
		JSON_DEF_URI : '<?php echo $def_uri; ?>',
		JSON_REMOTE_POST_URI : '<?php echo $remote_post_uri; ?>',
		JSON_LOCAL_POST_URI : '<?php echo $local_post_uri; ?>',
		MESSAGE1: '<?php _e('Corrupted response format. Contact the webmaster.','wikitip'); ?>',
		MESSAGE2: '<?php _e('Filed in','wikitip'); ?>',
		MESSAGE3: '<?php _e('under','wikitip'); ?>',
		MESSAGE4: '<?php _e('No comments yet','wikitip'); ?>',
		MESSAGE5: '<?php _e('Add comment','wikitip'); ?>',
		MESSAGE6: '<?php _e('comment','wikitip'); ?>',
		MESSAGE7: '<?php _e('comments','wikitip'); ?>',
		MESSAGE8: '<?php _e('Error','wikitip'); ?>',
		MESSAGE9: '<?php _e('There is no definition for this term. Please contact the website admin.','wikitip'); ?>',
		MESSAGE10: '<?php _e('wikis found','wikitip'); ?>',
		MESSAGE11: '<?php _e('A WikiTip Thesaurus','wikitip'); ?>'
	});
	 // -->
	</script>
<?php
}

function wikitip_displayon() {

	global $blog_id;
	global $post;
	$singular = 0;

	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
		
	if ( is_singular() ) {
		$singular = 1;
		if (get_post_meta($post->ID, 'wikitip_exclude', true))
			$singular = 0;
	}

	if ( ( $wikitip_options['loggedin'] == 1 && is_user_logged_in() ) || $wikitip_options['loggedin'] == 0) {
		if ( ( $singular == 1 && !is_front_page() || $wikitip_options['frontpage'] == 1 && is_front_page() ) ||
		( $wikitip_options['search'] == 1 && is_search() ) ||
		( $wikitip_options['archive'] == 1 && is_archive() ) ||
		( $wikitip_options['category'] == 1 && is_category() ) ||
		( $wikitip_options['author'] == 1 && is_author() ) ||
		( $wikitip_options['tag'] == 1 && is_tag() )
		) {
			add_action ('wp_footer','wikitip_load_header');
			add_action ('wp_print_footer_scripts','wikitip_load_footer', 99);
		}
	}	
}

function get_JSON_APIkey($nonce = null, $secret = null, $salt = null) {
	if ($nonce && $secret && $salt)
		return crypt($secret.$nonce, $salt);
}

/* Setup the admin options page */
function wikitip_admin_page() {

	add_options_page (

		__('WikiTip Settings Page','wikitip'),
		
		__('WikiTip','wikitip'),
		
		'manage_options',
		
		__FILE__,
		
		'wikitip_admin_settings_page'
	);
}

/*  Draw the option page */
function wikitip_admin_settings_page() {

	?>
	
	<div class="wrap">
	
		<?php screen_icon(); ?>
		
		<h2><?php _e('WikiTip Knowledge Cluster Tooltip for WordPress','wikitip'); ?></h2>
		
		<form action="options.php" method="post">
		
			<?php settings_fields('wikitip_options'); ?>
			
			<?php do_settings_sections('wikitip'); ?>
			
			<p><input name="Submit" type="submit" value="<?php _e('Save Changes','wikitip'); ?>" /></p>
			
		</form>
		
	</div>
	
	<?php
}

/* Register and define the settings */
function wikitip_admin_init(){

	register_setting(
		'wikitip_options',
		'wikitip_options',
		'wikitip_validate_options'
	);
	
	add_settings_section(
		'wikitip_main',
		__('Account information','wikitip'),
		'wikitip_section_text',
		'wikitip'
	);
	
	add_settings_field(
		'wikitip_username',
		__('Username','wikitip'),
		'wikitip_setting_input1',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_field(
		'wikitip_secret',
		__('Secret','wikitip'),
		'wikitip_setting_input2',
		'wikitip',
		'wikitip_main'
	);

	add_settings_field(
		'wikitip_salt',
		__('Encryption SALT (Blowfish)','wikitip'),
		'wikitip_setting_input3',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_field(
		'wikitip_domain',
		__('Your domain name. Be careful to include www if necessary.','wikitip'),
		'wikitip_setting_input4',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_field(
		'wikitip_cluster',
		__('The name of the Knowledge Cluster to use','wikitip'),
		'wikitip_setting_input5',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_field(
		'wikitip_minsize',
		__('The minimum size of terms to match','wikitip'),
		'wikitip_setting_input9',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_field(
		'wikitip_expr',
		__('Check to match expressions as well','wikitip'),
		'wikitip_setting_checkbox9',
		'wikitip',
		'wikitip_main'
	);
	
	add_settings_section(
		'wikitip_tooltip_options',
		__('Set tooltip usage options','wikitip'),
		'wikitip_section_text',
		'wikitip'
	);
	
	add_settings_field(
		'wikitip_casesensitive',
		__('Case sensitive match of terms','wikitip'),
		'wikitip_setting_checkbox1',
		'wikitip',
		'wikitip_tooltip_options'
	);
	
	add_settings_field(
		'wikitip_containers',
		__('Selector for containers containing text to search','wikitip'),
		'wikitip_setting_input6',
		'wikitip',
		'wikitip_tooltip_options'
	);
	
	add_settings_field(
		'wikitip_delay',
		__('Tooltip destruction delay (miliseconds)','wikitip'),
		'wikitip_setting_input7',
		'wikitip',
		'wikitip_tooltip_options'
	);

		add_settings_field(
		'wikitip_zindex',
		__('Tooltip z-index value','wikitip'),
		'wikitip_setting_input10',
		'wikitip',
		'wikitip_tooltip_options'
	);
	
	add_settings_field(
		'wikitip_effect',
		__('Tooltip construction effect','wikitip'),
		'wikitip_setting_input8',
		'wikitip',
		'wikitip_tooltip_options'
	);

	add_settings_section(
		'wikitip_display',
		__('Where to use tooltip besides single pages?','wikitip'),
		'wikitip_section_text',
		'wikitip'
	);
	
	add_settings_field(
		'wikitip_frontpage',
		__('Display on frontpage','wikitip'),
		'wikitip_setting_checkbox2',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_search',
		__('Display on search page','wikitip'),
		'wikitip_setting_checkbox3',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_archive',
		__('Display on archive pages','wikitip'),
		'wikitip_setting_checkbox4',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_category',
		__('Display on category pages','wikitip'),
		'wikitip_setting_checkbox5',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_author',
		__('Display on author pages','wikitip'),
		'wikitip_setting_checkbox6',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_tag',
		__('Display on tag pages','wikitip'),
		'wikitip_setting_checkbox7',
		'wikitip',
		'wikitip_display'
	);
	
	add_settings_field(
		'wikitip_members',
		__('Display only if users are logged in?','wikitip'),
		'wikitip_setting_checkbox8',
		'wikitip',
		'wikitip_display'
	);	
	
}

/*  Draw the section header */
function wikitip_section_text() {
	echo '<p>' . __('Enter your settings below.','wikitip') . '</p>';
}

/* Display and fill the form fields */
function wikitip_setting_input1() {

	/* Get option 'username' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['username'];
	
	/* Echo the field */
	echo "<input id='username' name='wikitip_options[username]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please enter your username from wikitip.info","wikitip")."</p>";
}

function wikitip_setting_input2() {

	/* Get option 'secret' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['secret'];
	
	/* Echo the field */
	echo "<input id='secret' name='wikitip_options[secret]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please copy your secret word from <a href='http://wikitip.info/my-subscription/'>My Subscription</a>","wikitip")."</p>";
}

function wikitip_setting_input3() {

	/* Get option 'salt' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['salt'];
	
	/* Echo the field */
	echo "<input id='salt' name='wikitip_options[salt]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please copy your encryption SALT from <a href='http://wikitip.info/my-subscription/'>My Subscription</a>","wikitip")."</p>";
}

function wikitip_setting_input4() {

	/* Get option 'domain' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['domain'];
	
	/* Echo the field */
	echo "<input id='domain' name='wikitip_options[domain]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert your domain and make sure it is corectly registered at <a href='http://wikitip.info/my-subscription/'>My Subscription</a>","wikitip")."</p>";
}

function wikitip_setting_input5() {
	/* Get option 'cluster' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['cluster'];
	
	/* Echo the field */
	echo "<input id='cluster' name='wikitip_options[cluster]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert the knowledge cluster you want to use, such as `mycluster` where the cluster address would be `mycluster.wikitip.info`.","wikitip")."</p>";
}

function wikitip_setting_input6() {

	/* Get option 'containers' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['containers'];
	
	/* Echo the field */
	echo "<input id='containers' name='wikitip_options[containers]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert the content containers to match the text for. It can be any HTML element such as `div.entry-content` or `strong` or `em`.","wikitip")."</p>";
}

function wikitip_setting_input7() {

	/* Get option 'delay' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['delay'];
	
	/* Echo the field */
	echo "<input id='delay' name='wikitip_options[delay]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert a tooltip destruction delay in miliseconds. It may be useful for accidental mouse moves outside the tooltip area.","wikitip")."</p>";
}

function wikitip_setting_input8() {

	/* Get option 'effect' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['effect'];
	
	/* Echo the field */
	echo "<input id='effect' name='wikitip_options[effect]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert the desired effect for tooltip display. Can be empty or `null`, `slide` and `fade`.","wikitip")."</p>";
}

function wikitip_setting_input9() {

	/* Get option 'minsize' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['minsize'];
	
	/* Echo the field */
	echo "<input id='minsize' name='wikitip_options[minsize]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert the minimum length of terms to be matched. Useful if you want to avoid matching short terms against a broad dictionary.","wikitip")."</p>";
}

function wikitip_setting_input10() {

	/* Get option 'zindex' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['zindex'];
	
	/* Echo the field */
	echo "<input id='zindex' name='wikitip_options[zindex]' type='text' value='$text_string' />";
	echo "<p class='description'>".__("Please insert a tooltip z-index value. It can help in the case the tooltip is not shown with default values in your theme.","wikitip")."</p>";
}

function wikitip_setting_checkbox1() {

	/* Get option 'casesensitive' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['casesensitive'];
	
	/* Echo the field */
	echo "<input id='casesensitive' name='wikitip_options[casesensitive]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want terms matching to be case sensitive.","wikitip")."</p>";
}

function wikitip_setting_checkbox2() {

	/* Get option 'frontpage' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['frontpage'];
	
	/* Echo the field */
	echo "<input id='frontpage' name='wikitip_options[frontpage]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the frontpage.","wikitip")."</p>";
}

function wikitip_setting_checkbox3() {

	/* Get option 'search' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['search'];
	
	/* Echo the field */
	echo "<input id='search' name='wikitip_options[search]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the search results page.","wikitip")."</p>";
}

function wikitip_setting_checkbox4() {

	/* Get option 'archive' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['archive'];
	
	/* Echo the field */
	echo "<input id='archive' name='wikitip_options[archive]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the archive pages.","wikitip")."</p>";
}

function wikitip_setting_checkbox5() {

	/* Get option 'category' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['category'];
	
	/* Echo the field */
	echo "<input id='category' name='wikitip_options[category]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the category pages.","wikitip")."</p>";
}

function wikitip_setting_checkbox6() {

	/* Get option 'author' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['author'];
	
	/* Echo the field */
	echo "<input id='author' name='wikitip_options[author]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the author pages.","wikitip")."</p>";
}

function wikitip_setting_checkbox7() {

	/* Get option 'tag' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['tag'];
	
	/* Echo the field */
	echo "<input id='tag' name='wikitip_options[tag]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the tag pages.","wikitip")."</p>";
}

function wikitip_setting_checkbox8() {

	/* Get option 'loggedin' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['loggedin'];
	
	/* Echo the field */
	echo "<input id='loggedin' name='wikitip_options[loggedin]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen in the selected pages only for logged in users.","wikitip")."</p>";
}

function wikitip_setting_checkbox9() {

	/* Get option 'expr' value from the database */
	global $blog_id;
	/* Read options */
	if (is_multisite())
		$wikitip_options = get_blog_option($blog_id , 'wikitip_options');
	else
		$wikitip_options = get_option('wikitip_options');
	
	$text_string = $wikitip_options['expr'];
	
	/* Echo the field */
	echo "<input id='expr' name='wikitip_options[expr]' type='checkbox' value='1' ";
	
	checked( 1 == $text_string );
	
	echo " />";
	echo "<p class='description'>".__("Please check if you want the matching to happen for expressions. Only check for small expression clusters. With huge clusters the performance will be decreased drastically.","wikitip")."</p>";
}

/* Validate user input */
function wikitip_validate_options( $input ) {

	$valid = array();
	
	$valid['delay'] = preg_replace( '/[^0-9]/', '', $input['delay'] );
	
	if( $valid['delay'] != $input['delay'] ) {
		
		$valid['delay'] = 250;
		add_settings_error(
			'wikitip_text_string',
			'wikitip_texterror',
			__('Incorrect value entered for delay number!','wikitip'),
			'error'
		);
	}

	$valid['minsize'] = preg_replace( '/[^0-9]/', '', $input['minsize'] );
	
	if( $valid['minsize'] != $input['minsize'] ) {
	
		$valid['minsize'] = 1;
		add_settings_error(
			'wikitip_text_string',
			'wikitip_texterror',
			__('Incorrect value entered for minimum size number!','wikitip'),
			'error'
		);
	}
	
	$valid['zindex'] = preg_replace( '/[^0-9]/', '', $input['zindex'] );
	
	if( !in_array( $input['zindex'], array( $valid['zindex'], 'auto', 'inherit' ) ) ) {
		
		add_settings_error(
			'wikitip_text_string',
			'wikitip_texterror',
			__('Incorrect value entered for z-index: it can be a number or `auto` or `inherit` only!' ,'wikitip'),
			'error'
		);
		$valid['zindex'] = 'auto';
	}
	else {
		$valid['zindex'] = $input['zindex'];
	}
	
	$valid['casesensitive'] = 0;
	
	if( isset( $input['casesensitive'] ) && ( 1 == $input['casesensitive'] ) )
	
        $valid['casesensitive'] = 1;
	
	$valid['frontpage'] = 0;
	
	if( isset( $input['frontpage'] ) && ( 1 == $input['frontpage'] ) )
	
        $valid['frontpage'] = 1;
		
	$valid['search'] = 0;
	
	if( isset( $input['search'] ) && ( 1 == $input['search'] ) )
	
        $valid['search'] = 1;
		
	$valid['archive'] = 0;
	
	if( isset( $input['archive'] ) && ( 1 == $input['archive'] ) )
	
        $valid['archive'] = 1;
		
	$valid['category'] = 0;
	
	if( isset( $input['category'] ) && ( 1 == $input['category'] ) )
	
        $valid['category'] = 1;
		
	$valid['tag'] = 0;
	
	if( isset( $input['tag'] ) && ( 1 == $input['tag'] ) )
	
        $valid['tag'] = 1;
		
	$valid['author'] = 0;
	
	if( isset( $input['author'] ) && ( 1 == $input['author'] ) )
	
        $valid['author'] = 1;
		
	$valid['loggedin'] = 0;
	
	if( isset( $input['loggedin'] ) && ( 1 == $input['loggedin'] ) )
	
        $valid['loggedin'] = 1;
		
	if( isset( $input['expr'] ) && ( 1 == $input['expr'] ) )
	
        $valid['expr'] = 1;

	if ( isset( $input['effect'] ) && !in_array( $input['effect'], array('','null','slide','fade') ) ) {
	
			add_settings_error(
			'wikitip_text_string',
			'wikitip_texterror',
			__('Incorrect effect name, can be only null, fade or slide!','wikitip'),
			'error'
		);
	
	}
	
	$valid['username'] = $input['username'];
	$valid['secret'] = $input['secret'];
	$valid['salt'] = $input['salt'];
	$valid['domain'] = $input['domain'];
	$valid['cluster'] = $input['cluster'];
	$valid['containers'] = $input['containers'];
	$valid['effect'] = $input['effect'];
		
	return $valid;
}

function wikitip_retrieve_blogs() {
	/* Retrieve all blog ids */

	global $wpdb, $wikitip_all_blogs;

	$sql = "SELECT blog_id FROM $wpdb->blogs";

	$wikitip_all_blogs = $wpdb->get_col($wpdb->prepare($sql));
}

function wikitip_url() {
	$pageURL = 'http';
	if ($_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
	$pageURL .= "://";
	if ($_SERVER["SERVER_PORT"] != "80") {
		$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
	} else {
		$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
	}
	return $pageURL;
}

?>